@@ -11,6 +11,6 @@ class PDF::Function::Stitching
 
     # see [PDF 1.7 TABLE 3.38 Additional entries specific to a type 3 function dictionary]
     has @.Functions is entry(:required);       #| (Required) An array of k 1-input functions making up the stitching function. The output dimensionality of all functions must be the same, and compatible with the value of Range if Range is present.
-    has Numeric @.Bound is entry(:required);   #| (Required) An array of k − 1 numbers that, in combination with Domain, define the intervals to which each function from the Functions array applies. Bounds elements must be in order of increasing value, and each value must be within the domain defined by Domain.
+    has Numeric @.Bounds is entry(:required);   #| (Required) An array of k − 1 numbers that, in combination with Domain, define the intervals to which each function from the Functions array applies. Bounds elements must be in order of increasing value, and each value must be within the domain defined by Domain.
     has Numeric @.Encode is entry(:required);  #| (Required) An array of 2 × k numbers that, taken in pairs, map each subset of the domain defined by Domain and the Bounds array to the domain of the corresponding function.
 }
